@@ -1,8 +1,8 @@
 # Net::CIDR
 #
-# Copyright 2001-2025 Sam Varshavchik.
+# Copyright 2001-2021 Sam Varshavchik.
 #
-# with contributions from David Cantrell and brian d foy
+# with contributions from David Cantrell.
 #
 # This program is free software; you can redistribute it
 # and/or modify it under the same terms as Perl itself.
@@ -50,7 +50,7 @@ use Carp;
 
 );
 
-$VERSION = "0.24.1";
+$VERSION = "0.21";
 
 1;
 
@@ -536,7 +536,7 @@ sub addr2cidr {
 	    $n &= 0xF8;
 	}
 
-	my $s=join(".", map { s/\A0+([0-9])/\1/; $_ } @ipcpy);
+	my $s=join(".", @ipcpy);
 
 	push @blocks, ($isipv6 ? _ipv4to6($s):$s) . "/$bits";
     }
@@ -872,7 +872,7 @@ sub cidr2octets {
 
 	$cidr =~ s/\s//g;
 
-	croak "CIDR \"$cidr\" doesn't look like a CIDR\n" unless ($cidr =~ /(.*)\/(.*)/);
+	croak "CIDR doesn't look like a CIDR\n" unless ($cidr =~ /(.*)\/(.*)/);
 
 	my ($ip, $pfix)=($1, $2);
 
@@ -1010,7 +1010,7 @@ sub cidradd {
     my @b;
 
     grep {
-	croak "Range $_ doesn't look like start-end\n" unless /(.*)-(.*)/;
+	croak "This doesn't look like start-end\n" unless /(.*)-(.*)/;
 	push @a, $1;
 	push @b, $2;
     } @cidr;
@@ -1178,7 +1178,7 @@ sub cidrlookup {
     my @b;
 
     grep {
-	croak "Range $_ doesn't look like start-end\n" unless /(.*)-(.*)/;
+	croak "This doesn't look like start-end\n" unless /(.*)-(.*)/;
 	push @a, $1;
 	push @b, $2;
     } @cidr;
@@ -1218,29 +1218,6 @@ undef.
 
 =cut
 
-sub _compress_ipv6 {
-    # taken from IPv6::Address on CPAN
-    my $str = shift;
-    return '::' if($str eq '0:0:0:0:0:0:0:0');
-    for(my $i=7;$i>1;$i--) {
-            my $zerostr = join(':',split('','0'x$i));
-            ###print "DEBUG: $str $zerostr \n";
-            if($str =~ /:$zerostr$/) {
-                    $str =~ s/:$zerostr$/::/;
-                    return $str;
-            }
-            elsif ($str =~ /:$zerostr:/) {
-                    $str =~ s/:$zerostr:/::/;
-                    return $str;
-            }
-            elsif ($str =~ /^$zerostr:/) {
-                    $str =~ s/^$zerostr:/::/;
-                    return $str;
-            }
-    }
-    return $str;
-}
-
 sub cidrvalidate {
     my $v=shift;
 
@@ -1320,10 +1297,9 @@ sub cidrvalidate {
 
     $v =~ s/([0-9A-Fa-f]+)/_triml0($1)/ge;
 
-	my $compressed = _compress_ipv6($v);
     foreach (addr2cidr($v))
     {
-	return $_ if $_ eq "$compressed/$suffix";
+	return $_ if $_ eq "$v/$suffix";
     }
     return undef;
 }
@@ -1352,7 +1328,6 @@ but the functions will croak if you're totally off the wall.
 Sam Varshavchik <sam@email-scan.com>
 
 With some contributions from David Cantrell <david@cantrell.org.uk>
-and brian d foy <briandfoy@pobox.com>.
 
 =cut
 
